@@ -54,11 +54,10 @@
 
 #include "config.h"
 
-static Lum::AppInfo   info;
-
-Lum::Images::ImageRef fullStar;
-Lum::Images::ImageRef emptyStar;
+static Lum::Def::AppInfo info;
 
+Lum::Images::ImageRef    fullStar;
+Lum::Images::ImageRef    emptyStar;
 
 class MainDialog : public Lum::Dialog
 {
